{{ define "content" }}
<div class="page-head">
  <h1>{{ T "nav.menu" }}</h1>
  <a class="btn primary btn-touch" href="/">← {{ T "menu.back_to_sale" }}</a>
</div>

<div class="menu-grid">
  {{ range .Tiles }}
  <a class="menu-tile" href="{{ .Href }}">
    <span class="menu-ico">{{ .Icon }}</span>
    <span class="menu-label">{{ T .Label }}</span>
  </a>
  {{ end }}
</div>

<div class="menu-lang">
  <span class="menu-lang-label">🌐 {{ T "setup.language.title" }}</span>
  <div class="menu-lang-btns">
    {{ range locales }}<a class="btn btn-touch menu-lang-btn{{ if eq . locale }} primary{{ else }} secondary{{ end }}" href="/menu?lang={{ . }}">{{ . }}</a>{{ end }}
  </div>
</div>
{{ end }}
