{{ define "content" }}
<div class="page-head">
  <h1>{{ T "designer.title" }}</h1>
  <span class="muted">{{ T "designer.reorder_hint" }}</span>
</div>

<div class="designer">
  <section>
    <h2>{{ T "designer.add_button" }}</h2>
    {{ template "buttons_admin" . }}
  </section>
</div>
{{ end }}
