{{ define "plugin_filters" }}
<div class="bg-white shadow rounded-lg p-4 mb-6">
	<form hx-get="/plugins/store" hx-target="#plugin-list" hx-trigger="change" class="grid grid-cols-1 md:grid-cols-3 gap-4">
		<div>
			<label for="type" class="block text-sm font-medium text-gray-700">{{ T "plugins.filter.type" }}</label>
			<select id="type" name="type" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
				<option value="">{{ T "plugins.filter.all_types" }}</option>
				<option value="page" {{ if eq .Filters.Type "page" }}selected{{ end }}>{{ T "plugins.type.page" }}</option>
				<option value="button" {{ if eq .Filters.Type "button" }}selected{{ end }}>{{ T "plugins.type.button" }}</option>
				<option value="payment" {{ if eq .Filters.Type "payment" }}selected{{ end }}>{{ T "plugins.type.payment" }}</option>
				<option value="report" {{ if eq .Filters.Type "report" }}selected{{ end }}>{{ T "plugins.type.report" }}</option>
				<option value="integration" {{ if eq .Filters.Type "integration" }}selected{{ end }}>{{ T "plugins.type.integration" }}</option>
				<option value="background_job" {{ if eq .Filters.Type "background_job" }}selected{{ end }}>{{ T "plugins.type.background_job" }}</option>
			</select>
		</div>

		<div>
			<label for="developer" class="block text-sm font-medium text-gray-700">{{ T "plugins.filter.developer" }}</label>
			<input type="text" id="developer" name="developer" value="{{ .Filters.Developer }}" 
				class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500"
				placeholder="{{ T "plugins.filter.developer_placeholder" }}">
		</div>

		<div>
			<label for="trust_tier" class="block text-sm font-medium text-gray-700">{{ T "plugins.filter.trust" }}</label>
			<select id="trust_tier" name="trust_tier" class="mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500">
				<option value="">{{ T "plugins.filter.all_tiers" }}</option>
				<option value="verified" {{ if eq .Filters.TrustTier "verified" }}selected{{ end }}>{{ T "plugins.tier.verified" }}</option>
				<option value="approved" {{ if eq .Filters.TrustTier "approved" }}selected{{ end }}>{{ T "plugins.tier.approved" }}</option>
				<option value="community" {{ if eq .Filters.TrustTier "community" }}selected{{ end }}>{{ T "plugins.tier.community" }}</option>
			</select>
		</div>
	</form>
</div>
{{ end }}
