{{ define "catalog_lookups" }}
<datalist id="categories-list">
  {{ range .Categories }}<option value="{{ .ID }}">{{ .Name }}</option>{{ end }}
</datalist>
<datalist id="brands-list">
  {{ range .Brands }}<option value="{{ .ID }}">{{ .Name }}</option>{{ end }}
</datalist>
<datalist id="taxcodes-list">
  {{ range .TaxCodes }}<option value="{{ .ID }}">{{ .Name }}</option>{{ end }}
</datalist>
{{ end }}
